@@ -2,11 +2,11 @@ from random_unicode_emoji.random_unicode_emoji import random_emoji
 
 __author__ = 'Nic Jones'
 __email__ = 'nic@nicpjones.com'
-__version__ = '2.4'
+__version__ = '2.7'
 __doc__ = """
 Random Unicode Emoji
 ====================
-A Python package and function to retrieve a random Unicode emoji.
+A simple Python package that returns random Unicode emojis.
 
 Install
 -------
@@ -20,11 +20,17 @@ Use the package:
 >>> from random_unicode_emoji import random_emoji
 >>> # Use the Function
 >>> print(random_emoji())
+>>> # Return Specific Count
+>>> print(random_emoji(count=3))
 >>> # Use Specific Version
 >>> print(random_emoji(version="15.0"))
+>>> # Append Custom Emoji
+>>> print(random_emoji(custom=['X.X',':D']))
+>>> # All Together Now
+>>> print(random_emoji(3, 15, ['X.X',':D']))
 
 Upgrade
 -------
-Upgrade the package to the version:
+Upgrade the package to the latest version:
 >>> pip install random-unicode-emoji -U
 """
